@@ -1,5 +1,8 @@
 use rui::*;
-use std::{thread, time};
+use std::{
+    thread::{sleep, spawn},
+    time::Duration,
+};
 
 fn main() {
     rui(state(
@@ -8,10 +11,10 @@ fn main() {
             let txt = s.get();
             hstack((
                 button(text("press to begin"), move || {
-                    thread::spawn(move || {
-                        s.set("task started".to_string());
-                        thread::sleep(time::Duration::from_secs(2));
-                        s.set("task complete".to_string());
+                    spawn(move || {
+                        on_main(move || s.set("task started".into()));
+                        sleep(Duration::from_secs(2));
+                        on_main(move || s.set("task complete".into()));
                     });
                 }),
                 text(&txt),
