@@ -1,6 +1,6 @@
-pub use crate::*;
-use std::rc::Rc;
+use crate::*;
 use std::cell::RefCell;
+use std::rc::Rc;
 
 /// Struct for the `tap` gesture.
 pub struct Tap<V, F> {
@@ -32,7 +32,7 @@ where
     fn process(&self, event: &Event, vid: ViewID, cx: &mut Context, vger: &mut VGER) {
         match &event.kind {
             EventKind::TouchBegin { id } => {
-                if let Some(_) = self.hittest(vid, event.position, cx, vger) {
+                if self.hittest(vid, event.position, cx, vger).is_some() {
                     cx.touches[*id] = vid;
                 }
             }
@@ -120,7 +120,7 @@ where
     fn process(&self, event: &Event, vid: ViewID, cx: &mut Context, vger: &mut VGER) {
         match &event.kind {
             EventKind::TouchBegin { id } => {
-                if let Some(_) = self.hittest(vid, event.position, cx, vger) {
+                if self.hittest(vid, event.position, cx, vger).is_some() {
                     cx.touches[*id] = vid;
                     cx.starts[*id] = event.position;
                     cx.previous_position[*id] = event.position;
@@ -184,8 +184,6 @@ where
 
 impl<V, F> private::Sealed for Drag<V, F> {}
 
-
-
 /// Struct for the `tap` gesture.
 pub struct Tap2<V, F> {
     child: V,
@@ -198,7 +196,10 @@ where
     F: FnMut() + 'a,
 {
     pub fn new(v: V, f: F) -> Self {
-        Self { child: v, func: Rc::new(RefCell::new(f)) }
+        Self {
+            child: v,
+            func: Rc::new(RefCell::new(f)),
+        }
     }
 }
 
@@ -216,7 +217,7 @@ where
     fn process(&self, event: &Event, vid: ViewID, cx: &mut Context, vger: &mut VGER) {
         match &event.kind {
             EventKind::TouchBegin { id } => {
-                if let Some(_) = self.hittest(vid, event.position, cx, vger) {
+                if self.hittest(vid, event.position, cx, vger).is_some() {
                     cx.touches[*id] = vid;
                 }
             }
@@ -266,4 +267,4 @@ where
     }
 }
 
-impl<V, F> private::Sealed for Tap2<V, F> {}
\ No newline at end of file
+impl<V, F> private::Sealed for Tap2<V, F> {}
