@@ -12,8 +12,8 @@ pub use event::*;
 mod binding;
 pub use binding::*;
 
-mod gstate;
-pub use gstate::*;
+mod state;
+pub use state::*;
 
 mod text;
 pub use text::*;
@@ -101,6 +101,7 @@ pub use window::*;
 
 use futures::executor::block_on;
 use std::collections::HashMap;
+
 use vger::color::*;
 use vger::*;
 
@@ -114,8 +115,6 @@ use tao::{
     window::{Window, WindowBuilder},
 };
 
-use std::env;
-
 #[macro_use]
 extern crate lazy_static;
 
@@ -222,7 +221,7 @@ fn make_menu_rec(
     if i == 0 {
         let mut app_menu = Menu::new();
 
-        let app_name = match env::current_exe() {
+        let app_name = match std::env::current_exe() {
             Ok(exe_path) => exe_path.file_name().unwrap().to_str().unwrap().to_string(),
             Err(_) => "rui".to_string(),
         };
@@ -233,7 +232,7 @@ fn make_menu_rec(
 
     for j in &items[i].submenu {
         let item = &items[*j];
-        if item.submenu.len() > 0 {
+        if !item.submenu.is_empty() {
             menu.add_submenu(
                 item.name.as_str(),
                 true,
@@ -268,7 +267,7 @@ fn build_menubar(
 
     for command in commands {
         let mut v = 0;
-        for name in command.path.split(":") {
+        for name in command.path.split(':') {
             if let Some(item) = items[v].submenu.iter().find(|x| items[**x].name == name) {
                 v = *item;
             } else {
@@ -363,6 +362,11 @@ pub fn rui(view: impl View + 'static) {
             }
             tao::event::Event::UserEvent(_) => {
                 // println!("received user event");
+
+                // Process the work queue.
+                while let Some(f) = GLOBAL_WORK_QUEUE.lock().unwrap().pop_front() {
+                    f();
+                }
             }
             tao::event::Event::MainEventsCleared => {
                 // Application update code.
@@ -382,7 +386,9 @@ pub fn rui(view: impl View + 'static) {
                         commands = new_commands;
 
                         command_map.clear();
-                        cx.window.as_ref().unwrap()
+                        cx.window
+                            .as_ref()
+                            .unwrap()
                             .set_menu(Some(build_menubar(&commands, &mut command_map)));
                     }
 
@@ -390,12 +396,14 @@ pub fn rui(view: impl View + 'static) {
                     let mut keep = vec![];
                     view.gc(cx.root_id, &mut cx, &mut keep);
                     {
-                        let mut map = GLOBAL_STATE_MAP.lock().unwrap();
-                        let mut new_map = StateMap::new();
-                        for id in keep {
-                            new_map.insert(id, map[&id].clone());
-                        }
-                        *map = new_map;
+                        STATE_MAP.with(|mapcell| {
+                            let mut map = mapcell.borrow_mut();
+                            let mut new_map = StateMap::new();
+                            for id in keep {
+                                new_map.insert(id, map[&id].clone());
+                            }
+                            *map = new_map;
+                        });
                     }
 
                     // Get a new accesskit tree.
@@ -572,7 +580,7 @@ mod tests {
         state(
             move || start,
             |count| {
-                let count2 = count.clone();
+                let count2 = count;
                 let value_string = format!("value: {:?}", count.get());
                 vstack((
                     text(value_string.as_str()),
@@ -591,7 +599,7 @@ mod tests {
     where
         B: Binding<usize> + Clone + 'static,
     {
-        let count2 = count.clone();
+        let count2 = count;
         vstack((
             button(text("increment"), move || {
                 count.with_mut(|value| *value += 1);
@@ -604,6 +612,6 @@ mod tests {
 
     #[test]
     fn test_binding() {
-        let _ = state(|| 42, |count| counter3(count));
+        let _ = state(|| 42, counter3);
     }
 }
