@@ -18,7 +18,12 @@ impl Paint {
     pub fn vger_paint(&self, vger: &mut VGER) -> PaintIndex {
         match self {
             Paint::Color(color) => vger.color_paint(*color),
-            Paint::Gradient { start, end, inner_color, outer_color } => vger.linear_gradient(*start, *end, *inner_color, *outer_color, 0.0)
+            Paint::Gradient {
+                start,
+                end,
+                inner_color,
+                outer_color,
+            } => vger.linear_gradient(*start, *end, *inner_color, *outer_color, 0.0),
         }
     }
 }
