@@ -47,7 +47,7 @@ impl View for Text {
 
     fn commands(&self, _id: ViewID, _cx: &mut Context, _cmds: &mut Vec<CommandInfo>) {}
 
-    fn gc(&self, _id: ViewID, _cx: &mut Context, _map: &mut StateMap) {
+    fn gc(&self, _id: ViewID, _cx: &mut Context, _map: &mut Vec<ViewID>) {
         // do nothing
     }
 
