@@ -1,21 +1,5 @@
 use crate::*;
 
-#[derive(Clone, Debug)]
-pub enum EventKind {
-    PressButton(String),
-    TouchBegin { id: usize },
-    TouchMove { id: usize },
-    TouchEnd { id: usize },
-    Command(String),
-    Key(KeyPress, ModifiersState),
-}
-
-#[derive(Clone, Debug)]
-pub struct Event {
-    pub kind: EventKind,
-    pub position: LocalPoint,
-}
-
 /// Trait for the unit of UI composition.
 pub trait View: private::Sealed {
     /// Prints a description of the view for debugging.
@@ -42,8 +26,8 @@ pub trait View: private::Sealed {
     /// Accumulates information about menu bar commands.
     fn commands(&self, id: ViewID, cx: &mut Context, cmds: &mut Vec<CommandInfo>);
 
-    /// Copies state currently in use to a new StateMap (the rest are dropped).
-    fn gc(&self, id: ViewID, cx: &mut Context, map: &mut StateMap);
+    // /// Copies state currently in use to a new StateMap (the rest are dropped).
+    fn gc(&self, _id: ViewID, _cx: &mut Context, _map: &mut Vec<ViewID>);
 
     /// Builds an AccessKit tree. The node ID for the subtree is returned. All generated nodes are accumulated.
     fn access(
@@ -83,7 +67,7 @@ impl View for EmptyView {
 
     fn commands(&self, _id: ViewID, _cx: &mut Context, _cmds: &mut Vec<CommandInfo>) {}
 
-    fn gc(&self, _id: ViewID, _cx: &mut Context, _map: &mut StateMap) {}
+    fn gc(&self, _id: ViewID, _cx: &mut Context, _map: &mut Vec<ViewID>) {}
 
     fn access(
         &self,
